==> polymake-2.9.7.tar.bz2: polymake-2.9.7/apps/common/java/javaview/StaticFrame.java <==
/* Copyright (c) 1997-2009
   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Darmstadt, Germany)
   http://www.polymake.de

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version: http://www.gnu.org/licenses/gpl.txt.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
--------------------------------------------------------------------------------
   $Project: polymake $$Id: StaticFrame.java 9298 2009-09-02 23:10:56Z gawrilow $
*/

package de.tuberlin.polymake.common.javaview;

import java.util.Properties;

import javax.swing.JFrame;

public class StaticFrame extends de.tuberlin.polymake.common.PolymakeFrame {

	protected Viewer jvv = null;
	
	private static final long serialVersionUID = -2140725600323643961L;

	public StaticFrame(de.tuberlin.polymake.common.EmbeddedGeometries geom, String title,
			Properties params, Properties iparams, de.tuberlin.polymake.common.PolymakeControl parent) {
		super(geom, title, params, iparams, parent);
		jvv = new Viewer(geometry);
		setMenuBar(jvv.getMenuBar());
		pViewer = jvv;
		setupFrame();
	}

	public void update(de.tuberlin.polymake.common.PointSet ps, Properties params) {
	}

	// @Override
	public JFrame createHelpFrame() {
		//TODO: Create proper help frames!
		return null;
	}
	
	public void encompass() {
		jvv.encompass();
	}

}

==> polymake-2.9.9.tar.bz2: polymake-2.9.9/apps/common/java/javaview/StaticFrame.java <==
/* Copyright (c) 1997-2009
   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Darmstadt, Germany)
   http://www.polymake.de

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version: http://www.gnu.org/licenses/gpl.txt.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
--------------------------------------------------------------------------------
   $Project: polymake $$Id: StaticFrame.java 9776 2010-08-26 11:10:03Z thilosch $
*/

package de.tuberlin.polymake.common.javaview;

import java.util.Properties;

import javax.swing.JFrame;

import de.tuberlin.polymake.common.PolymakeControl;
import de.tuberlin.polymake.common.PolymakeFrame;
import de.tuberlin.polymake.common.geometry.EmbeddedGeometries;
import de.tuberlin.polymake.common.geometry.PointSet;

public class StaticFrame extends PolymakeFrame {

	protected Viewer jvv = null;
	
	private static final long serialVersionUID = -2140725600323643961L;

	public StaticFrame(
			EmbeddedGeometries geom, 
			String title,
			Properties params, 
			Properties iparams, 
			PolymakeControl parent) 
	{
		super(geom, title, params, iparams, parent);
		jvv = new Viewer(geometry);
		setMenuBar(jvv.getMenuBar());
		pViewer = jvv;
		setupFrame();
	}

	public void update(PointSet ps, Properties params) {
	}

	// @Override
	public JFrame createHelpFrame() {
		//TODO: Create proper help frames!
		return null;
	}
	
	public void encompass() {
		jvv.encompass();
	}

}
